Package 'healthindexwales'

Title: What the Package Does (One Line, Title Case)
Description: What the package does (one paragraph).
Authors: First Last [aut, cre] (ORCID: YOUR-ORCID-ID)
Maintainer: First Last <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-06-05 08:45:36 UTC
Source: https://github.com/humaniverse/healthindexwales

Help Index


Rate of Patient Admissions for Alcohol Related Conditions per 100k (2023/24)

Description

A dataset containing statistics on the rate of patient admissions for all alcohol-related admissions per 100k in each Welsh Council, 2023/24.

Usage

lives_alcohol_misuse

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

alcohol_admissions_rate_per_100k

Rate of patient admissions per 100k population, based on population numbers per Local Authority

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://phw.nhs.wales/publications/publications1/data-mining-wales-the-annual-profile-for-substance-misuse-2023-2024/


Percentage of Cancer Screening Uptake (2021-22)

Description

A dataset containing statistics on the percentage of cancer screening uptake for bowel, breast, and cervical cancer in each Welsh Council, 2021-22.

Usage

lives_cancer_screening

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

total_cancer_screening_percentage

Percentage of cancer screening uptake; breast, bowel, and cervical cancer.

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://phw.nhs.wales/services-and-teams/screening/bowel-screening/programme-reports/uptake-coverage-by-local-authority-and-health-boards/

https://phw.nhs.wales/services-and-teams/cervical-screening-wales/information-resources/programme-reports/uptake-coverage-by-local-authority-and-health-boards/

https://phw.nhs.wales/services-and-teams/screening/breast-screening/programme-reports/uptake-coverage-by-local-authority-and-health-boards/


Percentage Rate of Cardiovascular Conditions (CHD, Atrial Fibrillation, Heart Failure, Stroke & TIA) (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA in Welsh Council Areas.

Usage

lives_cardiovascular_conditions

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

cardiovascular_conditions_percentage

Percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage of Childhood Vaccine Coverage (2023-2024)

Description

A dataset containing statistics on childhood vaccine coverage (aged 4 and under) in each Welsh Council, 2023/24.

Usage

lives_child_vaccination_coverage

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

child_vaccination_coverage_percentage

Percentage of vaccine coverage. Includes the following immunisations: Diphtheria, Tetanus, Pertussis, Polio, Haemophilus influenzae (Hib), Measles, Mumps, Rubella, Meningitis C and Pneumococcal infection (PCV).

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/flying-start/childrenlivinginflyingstartnonflyingstartareaswhoarefullyimmunisedbytheir4thbirthday-by-localauthority


Drug misuse per 1k (2024)

Description

A dataset containing statistics on the number of drug-related crimes recorded by the police, per 1,000 people, per Welsh Council (2024). Note, that these data have been aggregated up from the four police areas: Dyfed-Powys, Gwent and North and South Wales, and so repeated obersations will be seen across local authorities.

Usage

lives_drug_misuse

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

drug_misuse_per_1k

Average rate of drug offences per 1,000 people

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/crimeandjustice/datasets/policeforceareadatatables


Percentage of People that Eat Healthy (2021-22 and 2022-23)

Description

A dataset containing statistics on fruit and vegetable consumption in each Welsh Council, 2021-22 and 2022-23.

Usage

lives_healthy_eating

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

healthy_eating_percentage

Percentage of people that consume 5 portions or more of fruit and vegetable per day

year

Time periods combined

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index captures percentage of healthy eating per year, but Wales only has data combining over a 2 year period.

https://statswales.gov.wales/Catalogue/National-Survey-for-Wales/Population-Health/Adult-Lifestyles/adultlifestyles-by-healthboard-from-202021


Percentage of Adults Diagnosed with High Blood Pressure (2024)

Description

A dataset containing statistics on percentage of adults diagnosed with high blood pressure, by Council (2024).

Usage

lives_high_blood_pressure

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

high_blood_pressure_percentage

Percentage of adults diagnosed with high blood pressure

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage of Babies Born Not at a Healthy Birth Weight (2023)

Description

A dataset containing percentage babies born not at a healthy birth weight (<2,500g).

Usage

lives_low_birth_weight

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

low_birth_weight_percentage

Percentage of babies born not at a healthy birth weight (<2,500g)

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/Community-Child-Health/livebirthstowelshresidents-by-localhealthboard-birthweight


Average percentage of Adults Obese (2024)

Description

A dataset containing statistics on the average percentage of adults (aged 16+) clinically classed as obese in each Council, 2024.

Usage

lives_obesity_adults

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

obesity_adults_percentage

Average percentage of adults (aged 16+) clinically classed as overweight and obese

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index captures data on overweight and obese adults aged 16+. However, Wales only captures adults classed as obese. This has been included as the closest proxy.

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Average percentage of Children Overweight/Obese (2022/23)

Description

A dataset containing statistics on the average percentage of children clinically classed as overweight and obese in each Council, 2022/23.

Usage

lives_overweight_obesity_children

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

overweight_obesity_child_percentage

Average percentage of children clinically classed as overweight and obese aged 4/5

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index captures the percentage of children aged 4-5 and 10-11 respectively who are classed as being overweight or obese. However, the only available Welsh data captured overweight and obesity data for 4-5 year olds, so this has been included as the closest proxy here.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/flying-start/prevalenceofchildrenin-healthy-weight-categoriesforchildrenaged4to5yearsresidentwithinflyingstartandnonflyingstartareas-by-localauthority


Percentage of People Meeting Recommended Activity Levels (2021-22 and 2022-23)

Description

A dataset containing statistics on the percentage of people that meet the recommended activity levels of at least 150 minutes a week in each Welsh Council, 2021-22 and 2022-23.

Usage

lives_physical_activity

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

activity_levels_met_percentage

Percentage of people that meet the recommended activity levels of at least 150 minutes a week

year

Time periods over a 2 year period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/National-Survey-for-Wales/Population-Health/Adult-Lifestyles/adultlifestyles-by-healthboard-from-202021


Percentage of Pupil Absences (2023/24)

Description

A dataset containing statistics on the percentage of unauthorised school absences.

Usage

lives_pupil_absence

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

total_pupil_absence_percentage

Percentage of unauthorised school absences across primary and secondary schools

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index records the percentage of pupils (at state-funded primary and secondary, and special schools) who are persistent absentees, that is, have overall absences equating to 10% or more of their possible sessions. However, Wales only records percentage of half-day sessions missed for unauthorised absence for primary and secondary schools. This has been used as best proxy.

https://www.gov.wales/absenteeism-primary-schools-september-2023-august-2024

https://www.gov.wales/absenteeism-secondary-schools-september-2023-august-2024


Percentage of People Exhibiting Sedentary Behaviour (Very Low Activity Levels) (2021-22 and 2022-23)

Description

A dataset containing statistics on very low activity levels (less than 30 minutes a week) in each Council, 2021-22 and 2022-23.

Usage

lives_sedentary_behaviour

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

sedentary_behaviour_percentage

Percentage of people with very low activity levels, defined as less than 30 minutes activity a week

year

Time periods over a 2 year period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/National-Survey-for-Wales/Population-Health/Adult-Lifestyles/adultlifestyles-by-healthboard-from-202021


Percentage of Current Smokers (2021-21 and 2022-23)

Description

A dataset containing statistics on smoking status in each Welsh Council, 2021-21 and 2022-23.

Usage

lives_smoking

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

smoking_percentage

Percentage of people that are current smokers

year

Time periods over a 2 year period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/National-Survey-for-Wales/Population-Health/Adult-Lifestyles/adultlifestyles-by-healthboard-from-202021


Rates of teenage pregnancies per 1,000 (2021)

Description

A dataset containing statistics on the rate of teenage pregnancies (under 18) per 1k.

Usage

lives_teenage_pregnancy

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

teenage_pregnancies_per_1k

Rate of teenage pregnancies per 1k where teenagers are aged between 13 and 18

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/birthsdeathsandmarriages/conceptionandfertilityrates/datasets/conceptionstatisticsenglandandwalesreferencetables


Mortality all causes rate per 100k (2023)

Description

A dataset containing statistics from an age-sex standardised rate for all causes of mortality per 100k, by Council (2023).

Usage

people_all_mortality

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

all_deaths_per_100k

age-sex standardised rate for all causes of mortality per 100k

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/birthsdeathsandmarriages/deaths/datasets/deathsregisteredinenglandandwalesseriesdrreferencetables


Average Measurement of Anxiety Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of anxiety out of 10, by Council (2022-23).

Usage

people_anxiety

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

anxiety_score_out_of_10

Average personal ratings on feelings of anxiety out of 10 - 10 is most anxious, 1 is least anxious

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Rate of Avoidable Deaths per 100k (2020-2022)

Description

A dataset containing statistics on age-standardised death rates per 100k, by Welsh Council (2020-2022).

Usage

people_avoidable_mortality

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

avoidable_deaths_per_100k

Age-standardised avoidable mortality rates per 100k

year

3-year aggregate period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/healthandsocialcare/causesofdeath/datasets/avoidablemortalitybylocalauthorityinenglandandwales


Percentage Rate of Cancer (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having Cancer in Welsh Council Areas.

Usage

people_cancer

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

cancer_percentage

Percentage of people who self-reported as having Cancer

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage Rate of Dementia (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having Dementia in Welsh Council Areas.

Usage

people_dementia

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

dementia_percentage

Percentage of people who self-reported as having Dementia

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage Rate of Diabetes (Diabetes mellitus (patients aged 17+)) (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having Diabetes mellitus (aged 17+) in Welsh Council Areas.

Usage

people_diabetes

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

diabetes_percentage

Percentage of people who self-reported as having Diabetes mellitus

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage of People Aged 15-64 with Long-Term Health Problem/Disability that Limits Daily Activities

Description

A dataset containing statistics on the percentage of people aged 15-64 with long-term health problem/disability that limits daily activities, by Council (2021).

Usage

people_disability_daily_activities

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

disability_activities_limited_percentage

percentage of people aged 15-64 with long-term health problem/disability that limits daily activities by a lot or by a little.

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/healthandsocialcare/healthandwellbeing/bulletins/disabilityenglandandwales/census2021#:~:text=In%20Wales%2C%20in%202021%2C%20a,(21.2%25%2C%20567%2C000).


Average Measurement of Happiness Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of happiness out of 10, by Council (2022-23).

Usage

people_happiness

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

happiness_score_out_of_10

Average personal ratings on feelings of happiness out of 10 - 10 is most happy, 1 is least happy

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Average Life Expectancy for Men and Women (2021-2023)

Description

A dataset containing statistics on average life expectancy for men and women, by Welsh Council (2021-2023).

Usage

people_life_expectancy

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

life_expectancy_combined

Average life expectancy for men and women

year

Time period - three year aggregate

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/healthandsocialcare/healthandlifeexpectancies/datasets/lifeexpectancyforlocalareasofgreatbritain


Average Measurement of Life Satisfaction Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of life satisfaction out of 10, by Council (2022-23).

Usage

people_life_satisfaction

Format

A data frame with 11 rows and 3 variables:

ltla24_code

Local Authority Code

satisfaction_score_out_of_10

Average personal ratings on feelings of life satisfaction out of 10 - 10 is most satisfied, 1 is least satisfied

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Average Measurement of Life Worthwhileness Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of life worthwhileness out of 10, by Council (2022-23).

Usage

people_life_worthwhileness

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

worthwhile_score_out_of_10

Average personal ratings on feelings of life worthwhileness out of 10 - 10 is most worthwhile, 1 is least worthwhile

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Percentage Rate of Mental Health Conditions (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having a Mental Health Condition (aged 16+) in Welsh Council Areas.

Usage

people_mental_health

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

mental_health_percentage

Percentage of people who self-reported as having a Mental Health Condition

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage Rate of Musculoskeletal Conditions (Rheumatoid Arthritis (patients aged 16+)) (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having Rheumatoid Arthritis (aged 16+) in Welsh Council Areas.

Usage

people_musculoskeletal_conditions

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

musculoskeletal_conditions_percentage

Percentage of people who self-reported as having Rheumatoid Arthritis

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Percentage Rate of Respiratory Conditions (Asthma and COPD) (2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having asthma and/or COPD in Welsh Council Areas.

Usage

people_respiratory_conditions

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authroity Code

respiratory_conditions_percentage

Percentage of people who self-reported as having asthma and/or COPD

year

Snapshot of a single point in time in 2024 - specifically 1 April 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.

https://statswales.gov.wales/Catalogue/Health-and-Social-Care/NHS-Primary-and-Community-Activity/GMS-Contract/diseaseregisters-by-localhealthboard


Death Rate per 100k from Suicide (2021-2023)

Description

A dataset containing statistics on death rate per 100k by suicide, by Welsh Council.

Usage

people_suicide

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

suicide_rate_per_100k

Deaths from suicide (16+). Age standardised rate per 100,000.

year

Time period - 3 year aggregate

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/birthsdeathsandmarriages/deaths/datasets/suicidesbylocalauthority


Air pollution (2019)

Description

A dataset containing population-weighted annual mean PM2.5 data for 2019, by Welsh Council Area. Uses the anthropogenic component.

Usage

places_air_pollution

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

air_pollution_weighted

Population-weighted annual mean PM2.5

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://uk-air.defra.gov.uk/data/pcm-data


Percentage of Absolute Child Poverty (2022)

Description

A dataset containing statistics on the percentage of children under 16 experiencing absolute poverty, living in absolute low income families, by Local Authority, 2022.

Usage

places_child_poverty

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

child_poverty_percentage

Percentage of children (aged 16 and under) living in absolute low income families

year

Date

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Absolute poverty refers to people living in households with income below 60% of median income in a base year, usually 2010/11.

https://www.gov.uk/government/statistics/children-in-low-income-families-local-area-statistics-2014-to-2022


Ease of getting GP appointments at a convenient time (2021-22)

Description

The percentage of people finding it very difficult to get a GP appointment at a convenient time. Data is from the National Survey for Wales 2021-22, based on the question "How easy or difficult was it to get a convenient appointment?"

Usage

places_gp_appointments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 20 rows and 6 columns.

Details

The data is provided for Local Health Boards. We spread this data across each Local Authority within the Health Boards.

#' @format A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

gp_appointments_very_difficult

Percentage of people reporting it was very difficult to get a GP appointment at a convenient time

year

Year the survey was conducted

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.gov.wales/national-survey-wales-results-viewer


Travel time to GPs (2025)

Description

A dataset containing the average (median) travel time (in minutes) to the nearest GP in each Local Authority. This is based on the travel time to the nearest GP in each MSOA within a Local Authority.

Usage

places_gp_travel_time

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

gp_mean_travel_time

Mean travel time (in minutes) to the nearest GP among all the MSOAs within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Percentage Household Overcrowding (2021)

Description

A dataset containing statistics on the percentage of households experiencing household overcrowding, per Council (2021). Household overcrowding is defined as households with an occupancy rating of -1 or lower.

Usage

places_household_overcrowding

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

percentage_households_overcrowding

Percentage of households experiencing household overcrowding

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/housing/datasets/overcrowdingandunderoccupancybyhouseholdcharacteristicsenglandandwalescensus2021


Internet access (2024)

Description

Percentage of residential premises in each Local Authority that are below the Universal Service Obligation (USO) for broadband: no access to download speeds at or above 10 Mbit/s and upload speeds at or above 1 Mbit/s from fixed broadband or a Wireless Internet Service Provider (WISP) or Mobile FWA (including non-matched records and zero predicted speeds).

Usage

places_internet_access

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority code

poor_internet_access_percentage

% of premises below the Universal Service Obligation (USO) for broadband

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ofcom.org.uk/


Average rates of Low-Level Crime per 1k (2023-2024)

Description

A dataset containing statistics on the mean rate of low-level crime (bicycle theft and shoplifting) per 1,000, per Welsh Local Authority.

Usage

places_low_level_crime

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

low_level_crime_rate_per_1k

Average rate of low-level-crime (bicycle theft and shoplifting)

year

September 2023 - September 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/crimeandjustice/datasets/policeforceareadatatables


Average rates of Personal Crime per 1k (2023-2024)

Description

A dataset containing statistics on the mean rate of personal crime (Violence against the person, sexual offences, and criminal damage and arson) per 1,000, per Welsh Local Authority.

Usage

places_personal_crime

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

personal_crime_rate_per_1k

Average rate of low-level-crime (Violence against the person, sexual offences, and criminal damage and arson)

year

September 2023 - September 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/crimeandjustice/datasets/policeforceareadatatables


Travel time to pharmacies (2025)

Description

A dataset containing the average (median) travel time (in minutes) to the nearest pharmacy in each Local Authority. This is based on the travel time to the nearest sports centre in each MSOA within a Local Authority.

Usage

places_pharmacy_travel_time

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

pharmacy_mean_travel_time

Mean travel time (in minutes) to the nearest pharmacy among all the MSOAs within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Road safety (2023)

Description

A dataset containing number of people killed or injured in each Welsh Council Area in 2023 (latest revised and checked data available).

Usage

places_road_safety

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

road_accident_count

Number of people killed or injured, per Local Authority

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/Transport/Roads/Road-Accidents/Casualties/numberofcasualties-by-quarter-year-localauthority-policeforce


Travel time to sports facilities (2025)

Description

A dataset containing the average (mean) travel time (in minutes) to the nearest sports centre in each Local Authority. This is based on the travel time to the nearest sports centre in each MSOA within a Local Authority.

Usage

places_sports_centre_travel_time

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

sports_centre_mean_travel_time

Mean travel time (in minutes) to the nearest sports centre among all the MSOAs within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Percentage of People Experiencing Unemployment (2023-24)

Description

A dataset containing statistics on the percentage of people experiencing unemployment, excluding students.

Usage

places_unemployment

Format

A data frame with 22 rows and 3 variables:

ltla24_code

Local Authority Code

unemployment_percentage

Percentage of people experiencing unemployment excluding students. Ages 16-64.

year

September 2023 to September 2024

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://statswales.gov.wales/Catalogue/Business-Economy-and-Labour-Market/People-and-Work/Economic-Inactivity/economicinactivityratesexcludingstudents-by-welshlocalarea-year