| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | First Last [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: | First Last <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-05 08:45:36 UTC |
| Source: | https://github.com/humaniverse/healthindexwales |
A dataset containing statistics on the rate of patient admissions for all alcohol-related admissions per 100k in each Welsh Council, 2023/24.
lives_alcohol_misuselives_alcohol_misuse
A data frame with 22 rows and 3 variables:
Local Authority Code
Rate of patient admissions per 100k population, based on population numbers per Local Authority
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of cancer screening uptake for bowel, breast, and cervical cancer in each Welsh Council, 2021-22.
lives_cancer_screeninglives_cancer_screening
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of cancer screening uptake; breast, bowel, and cervical cancer.
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA in Welsh Council Areas.
lives_cardiovascular_conditionslives_cardiovascular_conditions
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on childhood vaccine coverage (aged 4 and under) in each Welsh Council, 2023/24.
lives_child_vaccination_coveragelives_child_vaccination_coverage
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of vaccine coverage. Includes the following immunisations: Diphtheria, Tetanus, Pertussis, Polio, Haemophilus influenzae (Hib), Measles, Mumps, Rubella, Meningitis C and Pneumococcal infection (PCV).
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the number of drug-related crimes recorded by the police, per 1,000 people, per Welsh Council (2024). Note, that these data have been aggregated up from the four police areas: Dyfed-Powys, Gwent and North and South Wales, and so repeated obersations will be seen across local authorities.
lives_drug_misuselives_drug_misuse
A data frame with 22 rows and 3 variables:
Local Authority Code
Average rate of drug offences per 1,000 people
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on fruit and vegetable consumption in each Welsh Council, 2021-22 and 2022-23.
lives_healthy_eatinglives_healthy_eating
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people that consume 5 portions or more of fruit and vegetable per day
Time periods combined
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index captures percentage of healthy eating per year, but Wales only has data combining over a 2 year period.
A dataset containing statistics on percentage of adults diagnosed with high blood pressure, by Council (2024).
lives_high_blood_pressurelives_high_blood_pressure
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of adults diagnosed with high blood pressure
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing percentage babies born not at a healthy birth weight (<2,500g).
lives_low_birth_weightlives_low_birth_weight
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of babies born not at a healthy birth weight (<2,500g)
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the average percentage of adults (aged 16+) clinically classed as obese in each Council, 2024.
lives_obesity_adultslives_obesity_adults
A data frame with 22 rows and 3 variables:
Local Authority Code
Average percentage of adults (aged 16+) clinically classed as overweight and obese
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index captures data on overweight and obese adults aged 16+. However, Wales only captures adults classed as obese. This has been included as the closest proxy.
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the average percentage of children clinically classed as overweight and obese in each Council, 2022/23.
lives_overweight_obesity_childrenlives_overweight_obesity_children
A data frame with 22 rows and 3 variables:
Local Authority Code
Average percentage of children clinically classed as overweight and obese aged 4/5
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index captures the percentage of children aged 4-5 and 10-11 respectively who are classed as being overweight or obese. However, the only available Welsh data captured overweight and obesity data for 4-5 year olds, so this has been included as the closest proxy here.
A dataset containing statistics on the percentage of people that meet the recommended activity levels of at least 150 minutes a week in each Welsh Council, 2021-22 and 2022-23.
lives_physical_activitylives_physical_activity
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people that meet the recommended activity levels of at least 150 minutes a week
Time periods over a 2 year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of unauthorised school absences.
lives_pupil_absencelives_pupil_absence
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of unauthorised school absences across primary and secondary schools
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index records the percentage of pupils (at state-funded primary and secondary, and special schools) who are persistent absentees, that is, have overall absences equating to 10% or more of their possible sessions. However, Wales only records percentage of half-day sessions missed for unauthorised absence for primary and secondary schools. This has been used as best proxy.
https://www.gov.wales/absenteeism-primary-schools-september-2023-august-2024
https://www.gov.wales/absenteeism-secondary-schools-september-2023-august-2024
A dataset containing statistics on very low activity levels (less than 30 minutes a week) in each Council, 2021-22 and 2022-23.
lives_sedentary_behaviourlives_sedentary_behaviour
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people with very low activity levels, defined as less than 30 minutes activity a week
Time periods over a 2 year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on smoking status in each Welsh Council, 2021-21 and 2022-23.
lives_smokinglives_smoking
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people that are current smokers
Time periods over a 2 year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the rate of teenage pregnancies (under 18) per 1k.
lives_teenage_pregnancylives_teenage_pregnancy
A data frame with 22 rows and 3 variables:
Local Authority Code
Rate of teenage pregnancies per 1k where teenagers are aged between 13 and 18
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics from an age-sex standardised rate for all causes of mortality per 100k, by Council (2023).
people_all_mortalitypeople_all_mortality
A data frame with 22 rows and 3 variables:
Local Authority Code
age-sex standardised rate for all causes of mortality per 100k
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of anxiety out of 10, by Council (2022-23).
people_anxietypeople_anxiety
A data frame with 22 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of anxiety out of 10 - 10 is most anxious, 1 is least anxious
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on age-standardised death rates per 100k, by Welsh Council (2020-2022).
people_avoidable_mortalitypeople_avoidable_mortality
A data frame with 22 rows and 3 variables:
Local Authority Code
Age-standardised avoidable mortality rates per 100k
3-year aggregate period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people who self-reported as having Cancer in Welsh Council Areas.
people_cancerpeople_cancer
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having Cancer
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the percentage of people who self-reported as having Dementia in Welsh Council Areas.
people_dementiapeople_dementia
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having Dementia
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the percentage of people who self-reported as having Diabetes mellitus (aged 17+) in Welsh Council Areas.
people_diabetespeople_diabetes
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having Diabetes mellitus
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the percentage of people aged 15-64 with long-term health problem/disability that limits daily activities, by Council (2021).
people_disability_daily_activitiespeople_disability_daily_activities
A data frame with 22 rows and 3 variables:
Local Authority Code
percentage of people aged 15-64 with long-term health problem/disability that limits daily activities by a lot or by a little.
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of happiness out of 10, by Council (2022-23).
people_happinesspeople_happiness
A data frame with 22 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of happiness out of 10 - 10 is most happy, 1 is least happy
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on average life expectancy for men and women, by Welsh Council (2021-2023).
people_life_expectancypeople_life_expectancy
A data frame with 22 rows and 3 variables:
Local Authority Code
Average life expectancy for men and women
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of life satisfaction out of 10, by Council (2022-23).
people_life_satisfactionpeople_life_satisfaction
A data frame with 11 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of life satisfaction out of 10 - 10 is most satisfied, 1 is least satisfied
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics of personal ratings on feelings of life worthwhileness out of 10, by Council (2022-23).
people_life_worthwhilenesspeople_life_worthwhileness
A data frame with 22 rows and 3 variables:
Local Authority Code
Average personal ratings on feelings of life worthwhileness out of 10 - 10 is most worthwhile, 1 is least worthwhile
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on the percentage of people who self-reported as having a Mental Health Condition (aged 16+) in Welsh Council Areas.
people_mental_healthpeople_mental_health
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having a Mental Health Condition
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the percentage of people who self-reported as having Rheumatoid Arthritis (aged 16+) in Welsh Council Areas.
people_musculoskeletal_conditionspeople_musculoskeletal_conditions
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having Rheumatoid Arthritis
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on the percentage of people who self-reported as having asthma and/or COPD in Welsh Council Areas.
people_respiratory_conditionspeople_respiratory_conditions
A data frame with 22 rows and 3 variables:
Local Authroity Code
Percentage of people who self-reported as having asthma and/or COPD
Snapshot of a single point in time in 2024 - specifically 1 April 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: StatsWales Disease Prevalence data only captures disease prevalence in a 'snapshot', or a single point of time. This means the year data represents when the data was extracted, not the period covered.
A dataset containing statistics on death rate per 100k by suicide, by Welsh Council.
people_suicidepeople_suicide
A data frame with 22 rows and 3 variables:
Local Authority Code
Deaths from suicide (16+). Age standardised rate per 100,000.
Time period - 3 year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing population-weighted annual mean PM2.5 data for 2019, by Welsh Council Area. Uses the anthropogenic component.
places_air_pollutionplaces_air_pollution
A data frame with 22 rows and 3 variables:
Local Authority Code
Population-weighted annual mean PM2.5
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://uk-air.defra.gov.uk/data/pcm-data
A dataset containing statistics on the percentage of children under 16 experiencing absolute poverty, living in absolute low income families, by Local Authority, 2022.
places_child_povertyplaces_child_poverty
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of children (aged 16 and under) living in absolute low income families
Date
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Absolute poverty refers to people living in households with income below 60% of median income in a base year, usually 2010/11.
The percentage of people finding it very difficult to get a GP appointment at a convenient time. Data is from the National Survey for Wales 2021-22, based on the question "How easy or difficult was it to get a convenient appointment?"
places_gp_appointmentsplaces_gp_appointments
An object of class tbl_df (inherits from tbl, data.frame) with 20 rows and 6 columns.
The data is provided for Local Health Boards. We spread this data across each Local Authority within the Health Boards.
#' @format A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people reporting it was very difficult to get a GP appointment at a convenient time
Year the survey was conducted
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.gov.wales/national-survey-wales-results-viewer
A dataset containing the average (median) travel time (in minutes) to the nearest GP in each Local Authority. This is based on the travel time to the nearest GP in each MSOA within a Local Authority.
places_gp_travel_timeplaces_gp_travel_time
A data frame with 22 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest GP among all the MSOAs within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of households experiencing household overcrowding, per Council (2021). Household overcrowding is defined as households with an occupancy rating of -1 or lower.
places_household_overcrowdingplaces_household_overcrowding
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of households experiencing household overcrowding
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Percentage of residential premises in each Local Authority that are below the Universal Service Obligation (USO) for broadband: no access to download speeds at or above 10 Mbit/s and upload speeds at or above 1 Mbit/s from fixed broadband or a Wireless Internet Service Provider (WISP) or Mobile FWA (including non-matched records and zero predicted speeds).
places_internet_accessplaces_internet_access
A data frame with 22 rows and 3 variables:
Local Authority code
% of premises below the Universal Service Obligation (USO) for broadband
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the mean rate of low-level crime (bicycle theft and shoplifting) per 1,000, per Welsh Local Authority.
places_low_level_crimeplaces_low_level_crime
A data frame with 22 rows and 3 variables:
Local Authority Code
Average rate of low-level-crime (bicycle theft and shoplifting)
September 2023 - September 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the mean rate of personal crime (Violence against the person, sexual offences, and criminal damage and arson) per 1,000, per Welsh Local Authority.
places_personal_crimeplaces_personal_crime
A data frame with 22 rows and 3 variables:
Local Authority Code
Average rate of low-level-crime (Violence against the person, sexual offences, and criminal damage and arson)
September 2023 - September 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the average (median) travel time (in minutes) to the nearest pharmacy in each Local Authority. This is based on the travel time to the nearest sports centre in each MSOA within a Local Authority.
places_pharmacy_travel_timeplaces_pharmacy_travel_time
A data frame with 22 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest pharmacy among all the MSOAs within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing number of people killed or injured in each Welsh Council Area in 2023 (latest revised and checked data available).
places_road_safetyplaces_road_safety
A data frame with 22 rows and 3 variables:
Local Authority Code
Number of people killed or injured, per Local Authority
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the average (mean) travel time (in minutes) to the nearest sports centre in each Local Authority. This is based on the travel time to the nearest sports centre in each MSOA within a Local Authority.
places_sports_centre_travel_timeplaces_sports_centre_travel_time
A data frame with 22 rows and 3 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest sports centre among all the MSOAs within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of people experiencing unemployment, excluding students.
places_unemploymentplaces_unemployment
A data frame with 22 rows and 3 variables:
Local Authority Code
Percentage of people experiencing unemployment excluding students. Ages 16-64.
September 2023 to September 2024
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...